package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.*;

/**
 * AnsibleSpec: configure an ansible host, and run ansible playbooks
 */
public class AnsibleSpec {
    @Nonnull private final AnsibleHostSpec ansibleHostSpec;
    @Nonnull private final List<AnsibleGalaxySpec> ansibleGalaxySpecs;
    @Nonnull private final List<AnsiblePlaybookSpec> ansiblePlaybookSpecs;
    @Nullable private final Map<String, List<String>> groups;

    public AnsibleSpec(@Nonnull AnsibleHostSpec ansibleHostSpec,
                       @Nullable List<AnsibleGalaxySpec> ansibleGalaxySpecs,
                       @Nullable List<AnsiblePlaybookSpec> ansiblePlaybookSpecs,
                       @Nullable Map<String, List<String>> groups) {
        this.ansibleHostSpec = ansibleHostSpec;
        this.ansibleGalaxySpecs = ansibleGalaxySpecs == null ? Collections.emptyList() :
                Collections.unmodifiableList(new ArrayList(ansibleGalaxySpecs));
        this.ansiblePlaybookSpecs = ansiblePlaybookSpecs == null ? Collections.emptyList() :
                Collections.unmodifiableList(new ArrayList(ansiblePlaybookSpecs));
        this.groups = groups == null ? null : unmodifiableGroupsCopy(groups);
    }

    @Nonnull
    private static Map<String, List<String>> unmodifiableGroupsCopy(@Nonnull Map<String, List<String>> orig) {
        Map<String, List<String>> res = new HashMap<>();
        for (Map.Entry<String, List<String>> e : orig.entrySet()) {
            res.put(e.getKey(), Collections.unmodifiableList(new ArrayList<>(e.getValue())));
        }
        return Collections.unmodifiableMap(res);
    }

    @Nonnull
    public AnsibleHostSpec getAnsibleHostSpec() {
        return ansibleHostSpec;
    }

    @Nonnull
    public List<AnsibleGalaxySpec> getAnsibleGalaxySpecs() {
        return ansibleGalaxySpecs;
    }

    @Nonnull
    public List<AnsiblePlaybookSpec> getAnsiblePlaybookSpecs() {
        return ansiblePlaybookSpecs;
    }

    @Nullable
    public Map<String, List<String>> getGroups() {
        return groups;
    }
}
