package be.iminds.ilabt.jfed.ui.cli2.instruction;


import com.fasterxml.jackson.annotation.JsonProperty;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

/**
 * CallOutput: instructions if and how the call detail output is handled
 *
 * The CLI will need to make calls to verious servers.
 * This determines if these have to be outputted for debugging purposes.
 * You can choose the output format, and the file/stream it is written to.
 */
public class CallOutput {
    public enum Format { JSON, XML, HTML, TEXT }

    @Nonnull private final Format format;
    @Nonnull private final OutputTarget target;
    @Nullable private final String filename;

    public CallOutput(@JsonProperty("format") @Nullable Format format,
                      @JsonProperty("target") @Nullable OutputTarget target,
                      @JsonProperty("filename") @Nullable String filename) {
        this.format = format == null ? new CallOutput().format : format;
        this.target = target == null ? new CallOutput().target : target;
        this.filename = filename == null ? new CallOutput().filename : filename;
    }

    public CallOutput() {
        this.format = Format.HTML;
        this.target = OutputTarget.FILE;
        this.filename = "experiment-calls.html";
    }

    @JsonProperty
    @Nonnull
    public Format getFormat() {
        return format;
    }

    @JsonProperty
    @Nonnull
    public OutputTarget getTarget() {
        return target;
    }

    @JsonProperty
    @Nullable
    public String getFilename() {
        return filename;
    }
}
